"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLoading = exports.useCache = exports.fromCache = exports.getCached = void 0;

var _react = _interopRequireDefault(require("react"));

var _axios = _interopRequireDefault(require("axios"));

var _lodash = require("lodash");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getCached = data => {
  const key = data.baseURL + data.url;
  const cache = localStorage.getItem(key);

  if (cache) {
    const {
      ETag,
      'Last-Modified': mod
    } = JSON.parse(cache);
    Object.assign(data.headers.common, {
      'If-Match': ETag,
      'If-Unmodified-Since': mod
    });
  }

  return data;
};

exports.getCached = getCached;

const fromCache = response => {
  const {
    data,
    headers,
    config: {
      url
    }
  } = response;
  localStorage.setItem(url, JSON.stringify({ ...headers,
    data
  }));
  return response;
};

exports.fromCache = fromCache;

const useCache = error => {
  if (!error.response) return error;
  const {
    config: {
      url
    },
    status
  } = error.response;

  if (status === 304) {
    const cache = localStorage.getItem(url);
    return cache ? Promise.resolve(JSON.parse(cache)) : window.location.reload();
  }

  if (status === 412) {
    // eslint-disable-next-line
    alert('Race condition detected! Please refresh your browser to prevent data overwrites.');
  }

  return Promise.reject((0, _lodash.get)(error, 'response'));
};

exports.useCache = useCache;

_axios.default.interceptors.request.use(getCached);

_axios.default.interceptors.response.use(fromCache, useCache);

const useLoading = () => {
  const [loading, setLoading] = _react.default.useState();

  _axios.default.interceptors.request.use(config => {
    setLoading(true);
    return config;
  }, error => {
    setLoading(false);
    return error;
  });

  _axios.default.interceptors.response.use(response => {
    setLoading(false);
    return response;
  }, error => {
    setLoading(false);
    return Promise.reject(error);
  });

  return loading;
};

exports.useLoading = useLoading;